Index — BAGO 0.0.1 documentation

# Index

B | C | D | E | F | G | O | P | R | S | U

## B

built-in function computeNextGradient() computeSecondGradient() dotProd() extractMS1() extractMS2() findTopSignals() fit() genSearchSpace() getBPCData() getMobilePhasePct() getUniqueMS2() getUniqueMz() outputConfig() plotBPC() readRawData() sepEfficiency() updateModel()

## C

computeNextGradient() built-in function | computeSecondGradient() built-in function

## D

dotProd() built-in function

## E

extractMS1() built-in function | extractMS2() built-in function

## F

findTopSignals() built-in function | fit() built-in function

## G

genSearchSpace() built-in function getBPCData() built-in function getMobilePhasePct() built-in function | getUniqueMS2() built-in function getUniqueMz() built-in function

## O

outputConfig() built-in function

## P

plotBPC() built-in function

## R

readRawData() built-in function

## S

sepEfficiency() built-in function

## U

updateModel() built-in function